package cn.teammodel.controller.admin.service.impl;

import cn.teammodel.controller.admin.service.*;
import cn.teammodel.model.dto.admin.common.FiveDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.Executor;
import java.util.concurrent.Executors;

@Service
public class FiveEducationServiceImpl implements FiveEducationService {

    @Autowired
    private ExamService examService;
    @Autowired
    private LaborEducationService laborEducationService;
    @Autowired
    private MoralEducationService  moralLaborService;
    @Autowired
    private TeacherService teacherService;
    @Autowired
    private ArtService artService;
    @Override
    public Map<String, Object> getAnalysis(FiveDto dto, HttpServletRequest request) {
        Map<String, Object> integratedResult = new ConcurrentHashMap<>();
        List<CompletableFuture<Void>> futures = new ArrayList<>();
        // 使用自定义线程池或公共线程池
        Executor executor = Executors.newFixedThreadPool(4); // 根据实际情况调整线程数

        // 1. 概况分析（异步执行）
        if (dto.getOverViewDto() != null) {
            futures.add(CompletableFuture.runAsync(() -> {
                integratedResult.put("overView", examService.getAnalysis(dto.getOverViewDto(), request));
            }, executor));
        }

       /* // 2. 艺术分析（异步执行）
        if (dto.getArtAnalysisDto() != null) {
            futures.add(CompletableFuture.runAsync(() -> {
                integratedResult.put("artAnalysis", artService.getArtAnalytics(dto.getArtAnalysisDto(), request));
            }, executor));
        }*/

        // 3. 德育分析（异步执行）
        if (dto.getMoralDto() != null) {
            futures.add(CompletableFuture.runAsync(() -> {
                integratedResult.put("moralAnalysis", laborEducationService.getAnalysis(dto.getMoralDto(), request));
            }, executor));
        }

        // 4. 劳育分析（异步执行）
        if (dto.getLaborDto() != null) {
            futures.add(CompletableFuture.runAsync(() -> {
                integratedResult.put("laborAnalysis", moralLaborService.getAnalysis(dto.getLaborDto(), request));
            }, executor));
        }
        // 5. 学生评价记录（异步执行）
        if (dto.getRecordDto() != null) {
            futures.add(CompletableFuture.runAsync(() -> {
                integratedResult.put("studentRecord", teacherService.getTeacherRecord(dto.getRecordDto(), request));
            }));
        }

        // 等待所有异步任务完成
        CompletableFuture.allOf(futures.toArray(new CompletableFuture[0])).join();

        return integratedResult;
    }
}
